PCB Environment: NavKeepoutCounts Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
NavKeepoutCounts Struct Reference

`#include <NavPoint.hpp>`

## Public Member Functions
void | setPin (int8_t n)
void | setPin (int8_t n, int8_t m)
void | setPinTracks (int8_t n)
void | setPinVias (int8_t n)
void | setRoute (int8_t n)
void | setRoute (int8_t n, int8_t m)
void | setRouteTracks (int8_t n)
void | setRouteVias (int8_t n)
void | reset ()
bool | isZero () const

## Data Fields
int8_t | _RouteTracks {0}
int8_t | _RouteVias {0}
int8_t | _PinTracks {0}
int8_t | _PinVias {0}
int8_t | Sum {0}
int8_t | RRRTrack {0}

## Detailed Description

This struct keeps track of how many routes and pins require a grid cell to be kept free. We need a count, as the clearance areas of multiple tracks and pins may overlap. Sometimes, parts of multiple tracks or pins themselves may even pass through the same cell. When we delete one source of keepout, this ensures the cell is still marked as occupied. FIXME: I forgot why routes and pins needed separate counts.

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/NavPoint.hpp